@@ -32,8 +32,8 @@ class ArticleItem(scrapy.Item):
     download_video = scrapy.Field()
     download_image = scrapy.Field()
     created_date = scrapy.Field()
-    crawl_comment = scrapy.Field()
-    comment_total_count = scrapy.Field()
+    crawl_comment = scrapy.Field()  # 是否爬取评论
+    comment_total_count = scrapy.Field()  # 评论总数
     err_msg = scrapy.Field()
     content_type = scrapy.Field()
     post_id = scrapy.Field()  # 所应平台的post id
@@ -57,6 +57,8 @@ class ArticleCommentItem(scrapy.Item):
     article_html = scrapy.Field()
     other_info = scrapy.Field()
     ip_label = scrapy.Field()  # 评论IP
+    reply_comment_id = scrapy.Field()  # 回复的评论ID
+    reply_comment_total = scrapy.Field()  # 评论的被回复数量
     upload_oss = scrapy.Field()
     download_video = scrapy.Field()
     download_image = scrapy.Field()
